


#include <glib-object.h>

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/dom.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/dom.h"
GType
dom_error_enum_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { DOM_ERROR_FAILED, "DOM_ERROR_FAILED", "failed" },
      { DOM_ERROR_INVALID_FORMAT, "DOM_ERROR_INVALID_FORMAT", "invalid-format" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("DomErrorEnum", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gio-utils.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gio-utils.h"
GType
gth_list_flags_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GTH_LIST_DEFAULT, "GTH_LIST_DEFAULT", "default" },
      { GTH_LIST_RECURSIVE, "GTH_LIST_RECURSIVE", "recursive" },
      { GTH_LIST_NO_FOLLOW_LINKS, "GTH_LIST_NO_FOLLOW_LINKS", "no-follow-links" },
      { GTH_LIST_NO_BACKUP_FILES, "GTH_LIST_NO_BACKUP_FILES", "no-backup-files" },
      { GTH_LIST_NO_HIDDEN_FILES, "GTH_LIST_NO_HIDDEN_FILES", "no-hidden-files" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GthListFlags", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gnome-desktop-thumbnail.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gnome-desktop-thumbnail.h"
GType
gnome_desktop_thumbnail_size_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GNOME_DESKTOP_THUMBNAIL_SIZE_NORMAL, "GNOME_DESKTOP_THUMBNAIL_SIZE_NORMAL", "normal" },
      { GNOME_DESKTOP_THUMBNAIL_SIZE_LARGE, "GNOME_DESKTOP_THUMBNAIL_SIZE_LARGE", "large" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GnomeDesktopThumbnailSize", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gsignature.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gsignature.h"
GType
g_signature_enc_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { G_SIGNATURE_ENC_HEX, "G_SIGNATURE_ENC_HEX", "hex" },
      { G_SIGNATURE_ENC_BASE64, "G_SIGNATURE_ENC_BASE64", "base64" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GSignatureEnc", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-browser.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-browser.h"
GType
gth_action_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_ACTION_GO_TO, "GTH_ACTION_GO_TO", "go-to" },
      { GTH_ACTION_GO_BACK, "GTH_ACTION_GO_BACK", "go-back" },
      { GTH_ACTION_GO_FORWARD, "GTH_ACTION_GO_FORWARD", "go-forward" },
      { GTH_ACTION_GO_UP, "GTH_ACTION_GO_UP", "go-up" },
      { GTH_ACTION_LIST_CHILDREN, "GTH_ACTION_LIST_CHILDREN", "list-children" },
      { GTH_ACTION_VIEW, "GTH_ACTION_VIEW", "view" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthAction", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-color-scale.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-color-scale.h"
GType
gth_color_scale_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_COLOR_SCALE_DEFAULT, "GTH_COLOR_SCALE_DEFAULT", "default" },
      { GTH_COLOR_SCALE_WHITE_BLACK, "GTH_COLOR_SCALE_WHITE_BLACK", "white-black" },
      { GTH_COLOR_SCALE_BLACK_WHITE, "GTH_COLOR_SCALE_BLACK_WHITE", "black-white" },
      { GTH_COLOR_SCALE_GRAY_BLACK, "GTH_COLOR_SCALE_GRAY_BLACK", "gray-black" },
      { GTH_COLOR_SCALE_GRAY_WHITE, "GTH_COLOR_SCALE_GRAY_WHITE", "gray-white" },
      { GTH_COLOR_SCALE_CYAN_RED, "GTH_COLOR_SCALE_CYAN_RED", "cyan-red" },
      { GTH_COLOR_SCALE_MAGENTA_GREEN, "GTH_COLOR_SCALE_MAGENTA_GREEN", "magenta-green" },
      { GTH_COLOR_SCALE_YELLOW_BLUE, "GTH_COLOR_SCALE_YELLOW_BLUE", "yellow-blue" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthColorScaleType", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-error.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-error.h"
GType
gth_error_code_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_ERROR_CANCELLED, "GTH_ERROR_CANCELLED", "cancelled" },
      { GTH_ERROR_GENERIC, "GTH_ERROR_GENERIC", "generic" },
      { GTH_ERROR_EXTENSION_DEPENDENCY, "GTH_ERROR_EXTENSION_DEPENDENCY", "extension-dependency" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthErrorCode", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-file-list.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-file-list.h"
GType
gth_file_list_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_FILE_LIST_MODE_NORMAL, "GTH_FILE_LIST_MODE_NORMAL", "normal" },
      { GTH_FILE_LIST_MODE_BROWSER, "GTH_FILE_LIST_MODE_BROWSER", "browser" },
      { GTH_FILE_LIST_MODE_SELECTOR, "GTH_FILE_LIST_MODE_SELECTOR", "selector" },
      { GTH_FILE_LIST_MODE_NO_SELECTION, "GTH_FILE_LIST_MODE_NO_SELECTION", "no-selection" },
      { GTH_FILE_LIST_MODE_V_SIDEBAR, "GTH_FILE_LIST_MODE_V_SIDEBAR", "v-sidebar" },
      { GTH_FILE_LIST_MODE_H_SIDEBAR, "GTH_FILE_LIST_MODE_H_SIDEBAR", "h-sidebar" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthFileListMode", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-file-view.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-file-view.h"
GType
gth_visibility_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_VISIBILITY_NONE, "GTH_VISIBILITY_NONE", "none" },
      { GTH_VISIBILITY_FULL, "GTH_VISIBILITY_FULL", "full" },
      { GTH_VISIBILITY_PARTIAL, "GTH_VISIBILITY_PARTIAL", "partial" },
      { GTH_VISIBILITY_PARTIAL_TOP, "GTH_VISIBILITY_PARTIAL_TOP", "partial-top" },
      { GTH_VISIBILITY_PARTIAL_BOTTOM, "GTH_VISIBILITY_PARTIAL_BOTTOM", "partial-bottom" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthVisibility", values);
  }
  return etype;
}
GType
gth_file_view_renderer_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_FILE_VIEW_RENDERER_CHECKBOX, "GTH_FILE_VIEW_RENDERER_CHECKBOX", "checkbox" },
      { GTH_FILE_VIEW_RENDERER_THUMBNAIL, "GTH_FILE_VIEW_RENDERER_THUMBNAIL", "thumbnail" },
      { GTH_FILE_VIEW_RENDERER_TEXT, "GTH_FILE_VIEW_RENDERER_TEXT", "text" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthFileViewRendererType", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-filter.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-filter.h"
GType
gth_limit_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_LIMIT_TYPE_NONE, "GTH_LIMIT_TYPE_NONE", "none" },
      { GTH_LIMIT_TYPE_FILES, "GTH_LIMIT_TYPE_FILES", "files" },
      { GTH_LIMIT_TYPE_SIZE, "GTH_LIMIT_TYPE_SIZE", "size" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthLimitType", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-grid-view.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-grid-view.h"
GType
gth_cursor_movement_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_CURSOR_MOVE_UP, "GTH_CURSOR_MOVE_UP", "up" },
      { GTH_CURSOR_MOVE_DOWN, "GTH_CURSOR_MOVE_DOWN", "down" },
      { GTH_CURSOR_MOVE_RIGHT, "GTH_CURSOR_MOVE_RIGHT", "right" },
      { GTH_CURSOR_MOVE_LEFT, "GTH_CURSOR_MOVE_LEFT", "left" },
      { GTH_CURSOR_MOVE_PAGE_UP, "GTH_CURSOR_MOVE_PAGE_UP", "page-up" },
      { GTH_CURSOR_MOVE_PAGE_DOWN, "GTH_CURSOR_MOVE_PAGE_DOWN", "page-down" },
      { GTH_CURSOR_MOVE_BEGIN, "GTH_CURSOR_MOVE_BEGIN", "begin" },
      { GTH_CURSOR_MOVE_END, "GTH_CURSOR_MOVE_END", "end" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthCursorMovement", values);
  }
  return etype;
}
GType
gth_drop_position_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_DROP_POSITION_NONE, "GTH_DROP_POSITION_NONE", "none" },
      { GTH_DROP_POSITION_INTO, "GTH_DROP_POSITION_INTO", "into" },
      { GTH_DROP_POSITION_LEFT, "GTH_DROP_POSITION_LEFT", "left" },
      { GTH_DROP_POSITION_RIGHT, "GTH_DROP_POSITION_RIGHT", "right" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthDropPosition", values);
  }
  return etype;
}
GType
gth_selection_change_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_SELECTION_KEEP, "GTH_SELECTION_KEEP", "keep" },
      { GTH_SELECTION_SET_CURSOR, "GTH_SELECTION_SET_CURSOR", "set-cursor" },
      { GTH_SELECTION_SET_RANGE, "GTH_SELECTION_SET_RANGE", "set-range" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthSelectionChange", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-histogram.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-histogram.h"
GType
gth_histogram_channel_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_HISTOGRAM_CHANNEL_VALUE, "GTH_HISTOGRAM_CHANNEL_VALUE", "channel-value" },
      { GTH_HISTOGRAM_CHANNEL_RED, "GTH_HISTOGRAM_CHANNEL_RED", "channel-red" },
      { GTH_HISTOGRAM_CHANNEL_GREEN, "GTH_HISTOGRAM_CHANNEL_GREEN", "channel-green" },
      { GTH_HISTOGRAM_CHANNEL_BLUE, "GTH_HISTOGRAM_CHANNEL_BLUE", "channel-blue" },
      { GTH_HISTOGRAM_CHANNEL_ALPHA, "GTH_HISTOGRAM_CHANNEL_ALPHA", "channel-alpha" },
      { GTH_HISTOGRAM_N_CHANNELS, "GTH_HISTOGRAM_N_CHANNELS", "n-channels" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthHistogramChannel", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-histogram-view.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-histogram-view.h"
GType
gth_histogram_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_HISTOGRAM_MODE_ONE_CHANNEL, "GTH_HISTOGRAM_MODE_ONE_CHANNEL", "one-channel" },
      { GTH_HISTOGRAM_MODE_ALL_CHANNELS, "GTH_HISTOGRAM_MODE_ALL_CHANNELS", "all-channels" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthHistogramMode", values);
  }
  return etype;
}
GType
gth_histogram_scale_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_HISTOGRAM_SCALE_LINEAR, "GTH_HISTOGRAM_SCALE_LINEAR", "linear" },
      { GTH_HISTOGRAM_SCALE_LOGARITHMIC, "GTH_HISTOGRAM_SCALE_LOGARITHMIC", "logarithmic" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthHistogramScale", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image.h"
GType
gth_image_format_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_IMAGE_FORMAT_CAIRO_SURFACE, "GTH_IMAGE_FORMAT_CAIRO_SURFACE", "format-cairo-surface" },
      { GTH_IMAGE_FORMAT_GDK_PIXBUF, "GTH_IMAGE_FORMAT_GDK_PIXBUF", "format-gdk-pixbuf" },
      { GTH_IMAGE_FORMAT_GDK_PIXBUF_ANIMATION, "GTH_IMAGE_FORMAT_GDK_PIXBUF_ANIMATION", "format-gdk-pixbuf-animation" },
      { GTH_IMAGE_N_FORMATS, "GTH_IMAGE_N_FORMATS", "n-formats" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthImageFormat", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-preloader.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-preloader.h"
GType
gth_load_policy_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_LOAD_POLICY_ONE_STEP, "GTH_LOAD_POLICY_ONE_STEP", "one-step" },
      { GTH_LOAD_POLICY_TWO_STEPS, "GTH_LOAD_POLICY_TWO_STEPS", "two-steps" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthLoadPolicy", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-selector.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-selector.h"
GType
gth_selector_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_SELECTOR_TYPE_REGION, "GTH_SELECTOR_TYPE_REGION", "region" },
      { GTH_SELECTOR_TYPE_POINT, "GTH_SELECTOR_TYPE_POINT", "point" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthSelectorType", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-viewer.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-viewer.h"
GType
gth_zoom_quality_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_ZOOM_QUALITY_HIGH, "GTH_ZOOM_QUALITY_HIGH", "high" },
      { GTH_ZOOM_QUALITY_LOW, "GTH_ZOOM_QUALITY_LOW", "low" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthZoomQuality", values);
  }
  return etype;
}
GType
gth_fit_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_FIT_NONE, "GTH_FIT_NONE", "none" },
      { GTH_FIT_SIZE, "GTH_FIT_SIZE", "size" },
      { GTH_FIT_SIZE_IF_LARGER, "GTH_FIT_SIZE_IF_LARGER", "size-if-larger" },
      { GTH_FIT_WIDTH, "GTH_FIT_WIDTH", "width" },
      { GTH_FIT_WIDTH_IF_LARGER, "GTH_FIT_WIDTH_IF_LARGER", "width-if-larger" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthFit", values);
  }
  return etype;
}
GType
gth_zoom_change_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_ZOOM_CHANGE_ACTUAL_SIZE, "GTH_ZOOM_CHANGE_ACTUAL_SIZE", "actual-size" },
      { GTH_ZOOM_CHANGE_KEEP_PREV, "GTH_ZOOM_CHANGE_KEEP_PREV", "keep-prev" },
      { GTH_ZOOM_CHANGE_FIT_SIZE, "GTH_ZOOM_CHANGE_FIT_SIZE", "fit-size" },
      { GTH_ZOOM_CHANGE_FIT_SIZE_IF_LARGER, "GTH_ZOOM_CHANGE_FIT_SIZE_IF_LARGER", "fit-size-if-larger" },
      { GTH_ZOOM_CHANGE_FIT_WIDTH, "GTH_ZOOM_CHANGE_FIT_WIDTH", "fit-width" },
      { GTH_ZOOM_CHANGE_FIT_WIDTH_IF_LARGER, "GTH_ZOOM_CHANGE_FIT_WIDTH_IF_LARGER", "fit-width-if-larger" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthZoomChange", values);
  }
  return etype;
}
GType
gth_transp_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_TRANSP_TYPE_WHITE, "GTH_TRANSP_TYPE_WHITE", "white" },
      { GTH_TRANSP_TYPE_NONE, "GTH_TRANSP_TYPE_NONE", "none" },
      { GTH_TRANSP_TYPE_BLACK, "GTH_TRANSP_TYPE_BLACK", "black" },
      { GTH_TRANSP_TYPE_CHECKED, "GTH_TRANSP_TYPE_CHECKED", "checked" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthTranspType", values);
  }
  return etype;
}
GType
gth_check_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_CHECK_TYPE_LIGHT, "GTH_CHECK_TYPE_LIGHT", "light" },
      { GTH_CHECK_TYPE_MIDTONE, "GTH_CHECK_TYPE_MIDTONE", "midtone" },
      { GTH_CHECK_TYPE_DARK, "GTH_CHECK_TYPE_DARK", "dark" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthCheckType", values);
  }
  return etype;
}
GType
gth_check_size_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_CHECK_SIZE_SMALL, "GTH_CHECK_SIZE_SMALL", "small" },
      { GTH_CHECK_SIZE_MEDIUM, "GTH_CHECK_SIZE_MEDIUM", "medium" },
      { GTH_CHECK_SIZE_LARGE, "GTH_CHECK_SIZE_LARGE", "large" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthCheckSize", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-metadata.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-metadata.h"
GType
gth_metadata_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_METADATA_TYPE_STRING, "GTH_METADATA_TYPE_STRING", "string" },
      { GTH_METADATA_TYPE_STRING_LIST, "GTH_METADATA_TYPE_STRING_LIST", "string-list" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthMetadataType", values);
  }
  return etype;
}
GType
gth_metadata_flags_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GTH_METADATA_ALLOW_NOWHERE, "GTH_METADATA_ALLOW_NOWHERE", "nowhere" },
      { GTH_METADATA_ALLOW_IN_FILE_LIST, "GTH_METADATA_ALLOW_IN_FILE_LIST", "in-file-list" },
      { GTH_METADATA_ALLOW_IN_PROPERTIES_VIEW, "GTH_METADATA_ALLOW_IN_PROPERTIES_VIEW", "in-properties-view" },
      { GTH_METADATA_ALLOW_IN_PRINT, "GTH_METADATA_ALLOW_IN_PRINT", "in-print" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GthMetadataFlags", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-metadata-provider.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-metadata-provider.h"
GType
gth_metadata_write_flags_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GTH_METADATA_WRITE_DEFAULT, "GTH_METADATA_WRITE_DEFAULT", "default" },
      { GTH_METADATA_WRITE_FORCE_EMBEDDED, "GTH_METADATA_WRITE_FORCE_EMBEDDED", "force-embedded" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GthMetadataWriteFlags", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-monitor.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-monitor.h"
GType
gth_monitor_event_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_MONITOR_EVENT_CREATED, "GTH_MONITOR_EVENT_CREATED", "created" },
      { GTH_MONITOR_EVENT_DELETED, "GTH_MONITOR_EVENT_DELETED", "deleted" },
      { GTH_MONITOR_EVENT_CHANGED, "GTH_MONITOR_EVENT_CHANGED", "changed" },
      { GTH_MONITOR_EVENT_REMOVED, "GTH_MONITOR_EVENT_REMOVED", "removed" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthMonitorEvent", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-overwrite-dialog.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-overwrite-dialog.h"
GType
gth_overwrite_response_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_OVERWRITE_RESPONSE_UNSPECIFIED, "GTH_OVERWRITE_RESPONSE_UNSPECIFIED", "unspecified" },
      { GTH_OVERWRITE_RESPONSE_YES, "GTH_OVERWRITE_RESPONSE_YES", "yes" },
      { GTH_OVERWRITE_RESPONSE_NO, "GTH_OVERWRITE_RESPONSE_NO", "no" },
      { GTH_OVERWRITE_RESPONSE_ALWAYS_YES, "GTH_OVERWRITE_RESPONSE_ALWAYS_YES", "always-yes" },
      { GTH_OVERWRITE_RESPONSE_ALWAYS_NO, "GTH_OVERWRITE_RESPONSE_ALWAYS_NO", "always-no" },
      { GTH_OVERWRITE_RESPONSE_RENAME, "GTH_OVERWRITE_RESPONSE_RENAME", "rename" },
      { GTH_OVERWRITE_RESPONSE_CANCEL, "GTH_OVERWRITE_RESPONSE_CANCEL", "cancel" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthOverwriteResponse", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-sidebar.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-sidebar.h"
GType
gth_sidebar_state_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_SIDEBAR_STATE_HIDDEN, "GTH_SIDEBAR_STATE_HIDDEN", "hidden" },
      { GTH_SIDEBAR_STATE_PROPERTIES, "GTH_SIDEBAR_STATE_PROPERTIES", "properties" },
      { GTH_SIDEBAR_STATE_TOOLS, "GTH_SIDEBAR_STATE_TOOLS", "tools" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthSidebarState", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-task.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-task.h"
GType
gth_task_error_enum_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_TASK_ERROR_FAILED, "GTH_TASK_ERROR_FAILED", "failed" },
      { GTH_TASK_ERROR_CANCELLED, "GTH_TASK_ERROR_CANCELLED", "cancelled" },
      { GTH_TASK_ERROR_SKIP_TO_NEXT_FILE, "GTH_TASK_ERROR_SKIP_TO_NEXT_FILE", "skip-to-next-file" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthTaskErrorEnum", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test.h"
GType
gth_match_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_MATCH_NO, "GTH_MATCH_NO", "no" },
      { GTH_MATCH_YES, "GTH_MATCH_YES", "yes" },
      { GTH_MATCH_LIMIT_REACHED, "GTH_MATCH_LIMIT_REACHED", "limit-reached" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthMatch", values);
  }
  return etype;
}
GType
gth_test_op_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_TEST_OP_NONE, "GTH_TEST_OP_NONE", "none" },
      { GTH_TEST_OP_EQUAL, "GTH_TEST_OP_EQUAL", "equal" },
      { GTH_TEST_OP_LOWER, "GTH_TEST_OP_LOWER", "lower" },
      { GTH_TEST_OP_GREATER, "GTH_TEST_OP_GREATER", "greater" },
      { GTH_TEST_OP_CONTAINS, "GTH_TEST_OP_CONTAINS", "contains" },
      { GTH_TEST_OP_CONTAINS_ALL, "GTH_TEST_OP_CONTAINS_ALL", "contains-all" },
      { GTH_TEST_OP_CONTAINS_ONLY, "GTH_TEST_OP_CONTAINS_ONLY", "contains-only" },
      { GTH_TEST_OP_STARTS_WITH, "GTH_TEST_OP_STARTS_WITH", "starts-with" },
      { GTH_TEST_OP_ENDS_WITH, "GTH_TEST_OP_ENDS_WITH", "ends-with" },
      { GTH_TEST_OP_MATCHES, "GTH_TEST_OP_MATCHES", "matches" },
      { GTH_TEST_OP_BEFORE, "GTH_TEST_OP_BEFORE", "before" },
      { GTH_TEST_OP_AFTER, "GTH_TEST_OP_AFTER", "after" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthTestOp", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test-chain.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test-chain.h"
GType
gth_match_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_MATCH_TYPE_NONE, "GTH_MATCH_TYPE_NONE", "none" },
      { GTH_MATCH_TYPE_ALL, "GTH_MATCH_TYPE_ALL", "all" },
      { GTH_MATCH_TYPE_ANY, "GTH_MATCH_TYPE_ANY", "any" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthMatchType", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test-simple.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test-simple.h"
GType
gth_test_data_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_TEST_DATA_TYPE_NONE, "GTH_TEST_DATA_TYPE_NONE", "none" },
      { GTH_TEST_DATA_TYPE_INT, "GTH_TEST_DATA_TYPE_INT", "int" },
      { GTH_TEST_DATA_TYPE_SIZE, "GTH_TEST_DATA_TYPE_SIZE", "size" },
      { GTH_TEST_DATA_TYPE_STRING, "GTH_TEST_DATA_TYPE_STRING", "string" },
      { GTH_TEST_DATA_TYPE_DATE, "GTH_TEST_DATA_TYPE_DATE", "date" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthTestDataType", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-user-dir.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-user-dir.h"
GType
gth_dir_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_DIR_CONFIG, "GTH_DIR_CONFIG", "config" },
      { GTH_DIR_CACHE, "GTH_DIR_CACHE", "cache" },
      { GTH_DIR_DATA, "GTH_DIR_DATA", "data" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthDir", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gtk-utils.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gtk-utils.h"
GType
gth_action_flags_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GTH_ACTION_FLAG_NONE, "GTH_ACTION_FLAG_NONE", "none" },
      { GTH_ACTION_FLAG_ALWAYS_SHOW_IMAGE, "GTH_ACTION_FLAG_ALWAYS_SHOW_IMAGE", "always-show-image" },
      { GTH_ACTION_FLAG_IS_IMPORTANT, "GTH_ACTION_FLAG_IS_IMPORTANT", "is-important" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GthActionFlags", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/pixbuf-cache.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/pixbuf-cache.h"
GType
pixbuf_cache_channel_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { PIXBUF_CACHE_CHANNEL_VALUE, "PIXBUF_CACHE_CHANNEL_VALUE", "value" },
      { PIXBUF_CACHE_CHANNEL_RED, "PIXBUF_CACHE_CHANNEL_RED", "red" },
      { PIXBUF_CACHE_CHANNEL_GREEN, "PIXBUF_CACHE_CHANNEL_GREEN", "green" },
      { PIXBUF_CACHE_CHANNEL_BLUE, "PIXBUF_CACHE_CHANNEL_BLUE", "blue" },
      { PIXBUF_CACHE_CHANNEL_ALPHA, "PIXBUF_CACHE_CHANNEL_ALPHA", "alpha" },
      { PIXBUF_CACHE_CHANNEL_SIZE, "PIXBUF_CACHE_CHANNEL_SIZE", "size" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("PixbufCacheChannel", values);
  }
  return etype;
}

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/typedefs.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/typedefs.h"
GType
gth_click_policy_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_CLICK_POLICY_NAUTILUS, "GTH_CLICK_POLICY_NAUTILUS", "nautilus" },
      { GTH_CLICK_POLICY_SINGLE, "GTH_CLICK_POLICY_SINGLE", "single" },
      { GTH_CLICK_POLICY_DOUBLE, "GTH_CLICK_POLICY_DOUBLE", "double" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthClickPolicy", values);
  }
  return etype;
}
GType
gth_direction_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_DIRECTION_FORWARD, "GTH_DIRECTION_FORWARD", "forward" },
      { GTH_DIRECTION_REVERSE, "GTH_DIRECTION_REVERSE", "reverse" },
      { GTH_DIRECTION_RANDOM, "GTH_DIRECTION_RANDOM", "random" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthDirection", values);
  }
  return etype;
}
GType
gth_toolbar_style_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_TOOLBAR_STYLE_SYSTEM, "GTH_TOOLBAR_STYLE_SYSTEM", "system" },
      { GTH_TOOLBAR_STYLE_TEXT_BELOW, "GTH_TOOLBAR_STYLE_TEXT_BELOW", "text-below" },
      { GTH_TOOLBAR_STYLE_TEXT_BESIDE, "GTH_TOOLBAR_STYLE_TEXT_BESIDE", "text-beside" },
      { GTH_TOOLBAR_STYLE_ICONS, "GTH_TOOLBAR_STYLE_ICONS", "icons" },
      { GTH_TOOLBAR_STYLE_TEXT, "GTH_TOOLBAR_STYLE_TEXT", "text" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthToolbarStyle", values);
  }
  return etype;
}
GType
gth_transform_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_TRANSFORM_NONE, "GTH_TRANSFORM_NONE", "none" },
      { GTH_TRANSFORM_FLIP_H, "GTH_TRANSFORM_FLIP_H", "flip-h" },
      { GTH_TRANSFORM_ROTATE_180, "GTH_TRANSFORM_ROTATE_180", "rotate-180" },
      { GTH_TRANSFORM_FLIP_V, "GTH_TRANSFORM_FLIP_V", "flip-v" },
      { GTH_TRANSFORM_TRANSPOSE, "GTH_TRANSFORM_TRANSPOSE", "transpose" },
      { GTH_TRANSFORM_ROTATE_90, "GTH_TRANSFORM_ROTATE_90", "rotate-90" },
      { GTH_TRANSFORM_TRANSVERSE, "GTH_TRANSFORM_TRANSVERSE", "transverse" },
      { GTH_TRANSFORM_ROTATE_270, "GTH_TRANSFORM_ROTATE_270", "rotate-270" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthTransform", values);
  }
  return etype;
}
GType
gth_unit_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_UNIT_PIXELS, "GTH_UNIT_PIXELS", "pixels" },
      { GTH_UNIT_PERCENTAGE, "GTH_UNIT_PERCENTAGE", "percentage" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthUnit", values);
  }
  return etype;
}
GType
gth_metric_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_METRIC_PIXELS, "GTH_METRIC_PIXELS", "pixels" },
      { GTH_METRIC_MILLIMETERS, "GTH_METRIC_MILLIMETERS", "millimeters" },
      { GTH_METRIC_INCHES, "GTH_METRIC_INCHES", "inches" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthMetric", values);
  }
  return etype;
}
GType
gth_aspect_ratio_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_ASPECT_RATIO_NONE, "GTH_ASPECT_RATIO_NONE", "none" },
      { GTH_ASPECT_RATIO_SQUARE, "GTH_ASPECT_RATIO_SQUARE", "square" },
      { GTH_ASPECT_RATIO_IMAGE, "GTH_ASPECT_RATIO_IMAGE", "image" },
      { GTH_ASPECT_RATIO_DISPLAY, "GTH_ASPECT_RATIO_DISPLAY", "display" },
      { GTH_ASPECT_RATIO_5x4, "GTH_ASPECT_RATIO_5x4", "5x4" },
      { GTH_ASPECT_RATIO_4x3, "GTH_ASPECT_RATIO_4x3", "4x3" },
      { GTH_ASPECT_RATIO_7x5, "GTH_ASPECT_RATIO_7x5", "7x5" },
      { GTH_ASPECT_RATIO_3x2, "GTH_ASPECT_RATIO_3x2", "3x2" },
      { GTH_ASPECT_RATIO_16x10, "GTH_ASPECT_RATIO_16x10", "16x10" },
      { GTH_ASPECT_RATIO_16x9, "GTH_ASPECT_RATIO_16x9", "16x9" },
      { GTH_ASPECT_RATIO_185x100, "GTH_ASPECT_RATIO_185x100", "185x100" },
      { GTH_ASPECT_RATIO_239x100, "GTH_ASPECT_RATIO_239x100", "239x100" },
      { GTH_ASPECT_RATIO_CUSTOM, "GTH_ASPECT_RATIO_CUSTOM", "custom" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthAspectRatio", values);
  }
  return etype;
}
GType
gth_overwrite_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_OVERWRITE_SKIP, "GTH_OVERWRITE_SKIP", "skip" },
      { GTH_OVERWRITE_RENAME, "GTH_OVERWRITE_RENAME", "rename" },
      { GTH_OVERWRITE_ASK, "GTH_OVERWRITE_ASK", "ask" },
      { GTH_OVERWRITE_OVERWRITE, "GTH_OVERWRITE_OVERWRITE", "overwrite" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthOverwriteMode", values);
  }
  return etype;
}
GType
gth_grid_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_GRID_NONE, "GTH_GRID_NONE", "none" },
      { GTH_GRID_THIRDS, "GTH_GRID_THIRDS", "thirds" },
      { GTH_GRID_GOLDEN, "GTH_GRID_GOLDEN", "golden" },
      { GTH_GRID_CENTER, "GTH_GRID_CENTER", "center" },
      { GTH_GRID_UNIFORM, "GTH_GRID_UNIFORM", "uniform" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthGridType", values);
  }
  return etype;
}



